//@line 36 "/builds/slave/linux_repack/build/releases/l10n-mozilla-1.9.1/fa/browser/firefox-l10n.js"

//@line 38 "/builds/slave/linux_repack/build/releases/l10n-mozilla-1.9.1/fa/browser/firefox-l10n.js"

pref("general.useragent.locale", "fa");

// Use the bidi UI controls
pref("browser.bidi.ui", true);

// RTL SCROLL
//pref("mousewheel.horizscroll.withaltkey.numlines", 1);
//pref("mousewheel.horizscroll.withcontrolkey.numlines", 1);
//pref("mousewheel.horizscroll.withmetakey.numlines", 1);
//pref("mousewheel.horizscroll.withnokey.numlines", 1);
//pref("mousewheel.horizscroll.withshiftkey.numlines", 1);
